from datoso_plugin_internetarchive.fetch import fetch_helper
from datoso_plugin_internetarchive.ia import Archive
from datoso.configuration.folder_helper import Folders
from datoso_seed_md_enhanced import __preffix__

def fetch():
    folder_helper = Folders(seed=__preffix__)
    folder_helper.clean_dats()
    folder_helper.create_all()
    archive = Archive(dat_folder='DATs', item='SegaMD-Enhanced-ROMs')
    fetch_helper(archive, folder_helper, __preffix__)



import re
from datoso.configuration import config
from datoso.repositories.dat import XMLDatFile

class MdEnhancedDat(XMLDatFile):
    """ MegaDrive Enhanced Colors Dat class. """
    seed: str = 'md_enhanced'

    def initial_parse(self):
        # pylint: disable=R0801
        """ Parse the dat file. """
        name = self.name

        name_array = name.split(' - ')
        if len(name_array) == 2:
            company, system = name_array
        if len(name_array) == 3:
            company, system, suffix = name_array
            self.suffix = suffix
        self.company = company
        self.system = system
        self.overrides()

        if self.modifier or self.system_type:
            self.preffix = config.get('PREFFIXES', self.modifier or self.system_type, fallback='')
        else:
            self.preffix = None

        return [self.preffix, self.company, self.system, self.suffix, self.get_date()]


    def get_date(self):
        """ Get the date from the dat file. """
        if self.file:
            result = re.findall(r'\(.*?\)', self.file)
            self.date = result[len(result)-1][1:-1]
        return self.date



from datoso_seed_md_enhanced.dats import MdEnhancedDat

actions = {
    '{dat_origin}': [
        {
            'action': 'LoadDatFile',
            '_class': MdEnhancedDat
        },
        {
            'action': 'DeleteOld'
        },
        {
            'action': 'Copy',
            'folder': '{dat_destination}'
        },
        {
            'action': 'SaveToDatabase'
        }
    ]
}

def get_actions():
    return actions



from datoso_seed_md_enhanced.dats import MdEnhancedDat

rules = [
    {
        'name': '32X MD+ Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': '32X'
            },
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'MD+'
            }
        ]
    },
    {
        'name': '32X MSU-MD Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': '32X'
            },
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'MSU-MD'
            }
        ]
    },
    {
        'name': 'Sega CD Hacks Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Mega CD Hacks'
            }
        ]
    },
    {
        'name': 'Mega Drive Enhanced Colors Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Mega Drive'
            },
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Enhanced Colors'
            }
        ]
    },
    {
        'name': 'Mega Drive MD+ Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Mega Drive'
            },
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'MD+'
            }
        ]
    },
    {
        'name': 'Mega Drive Mode 1 CD Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Mega Drive'
            },
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Mode 1 CD'
            }
        ]
    },
    {
        'name': 'Mega Drive MSU-MD Dat',
        '_class': MdEnhancedDat,
        'seed': 'md_enhanced',
        'priority': 50,
        'rules': [
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'Mega Drive'
            },
            {
                'key': 'name',
                'operator': 'contains',
                'value': 'MSU-MD'
            }
        ]
    }
]


def get_rules():
    return rules


"""
__init__.py
"""
__all__ = ["__version__", "__author__", "__description__"]
__version__ = "0.2.3"
__author__ = "Lacides Miranda"
__description__ = "MegaDrive - Genesis Enhanced"
__preffix__ = "md_enhanced"
